@@ -17,7 +17,7 @@ dm_nrow <- function(dm) {
   # FIXME: with "direct" filter maybe no check necessary: but do we want to issue
   # a message in case the filters haven't been applied yet?
   check_no_filter(dm)
-  map_dbl(dm_get_tables_impl(dm), ~ as.numeric(pull(collect(count(.)))))
+  map_dbl(dm_get_tables_impl(dm), ~ as.numeric(pull(collect(safe_count(.)))))
 }
 
 get_by <- function(dm, lhs_name, rhs_name) {
