@@ -33,7 +33,19 @@
 #'
 #' @export
 #' @examples
-#' nycflights_dm <- dm_from_src(dplyr::src_df(pkg = "nycflights13"))
+#' if (rlang::is_installed("nycflights13")) {
+#'   nycflights_dm <- dm(
+#'     planes = nycflights13::planes,
+#'     flights = nycflights13::flights
+#'   )
+#' } else {
+#'   message("Using mock-up data, install the nycflights13 package to fix.")
+#'   nycflights_dm <- dm(
+#'     planes = tibble(tailnum = character()),
+#'     flights = tibble(tailnum = character())
+#'   )
+#' }
+#'
 #' nycflights_dm %>%
 #'   dm_draw()
 #'
@@ -73,8 +85,20 @@ dm_add_fk_impl <- function(dm, table, column, ref_table) {
   def <- dm_get_def(dm)
 
   i <- which(def$table == ref_table)
+
+  fks <- def$fks[[i]]
+
+  existing <- fks$table == table & !is.na(vctrs::vec_match(fks$column, list(column)))
+  if (any(existing)) {
+    if (dm_is_strict_keys(dm)) {
+      abort_fk_exists(table, column, ref_table)
+    }
+
+    return(dm)
+  }
+
   def$fks[[i]] <- vctrs::vec_rbind(
-    def$fks[[i]],
+    fks,
     new_fk(table, list(column))
   )
 
@@ -199,12 +223,9 @@ dm_get_all_fks_impl <- function(dm) {
 #' @export
 #' @examples
 #'
-#' dm_rm_fk(
-#'   dm_nycflights13(cycle = TRUE),
-#'   flights,
-#'   dest,
-#'   airports
-#' )
+#' dm_nycflights13(cycle = TRUE) %>%
+#'   dm_rm_fk(flights, dest, airports) %>%
+#'   dm_draw()
 dm_rm_fk <- function(dm, table, columns, ref_table) {
   check_not_zoomed(dm)
 
@@ -220,7 +241,8 @@ dm_rm_fk <- function(dm, table, columns, ref_table) {
 
   fk_cols <- dm_get_fk_impl(dm, table_name, ref_table_name)
   if (is_empty(fk_cols)) {
-    return(dm)
+    # FIXME: Simplify, check is already done in dm_rm_fk_impl()
+    abort_is_not_fkc(table_name, fk_cols, ref_table_name)
   }
 
   if (quo_is_null(column_quo)) {
@@ -228,16 +250,12 @@ dm_rm_fk <- function(dm, table, columns, ref_table) {
   } else {
     # FIXME: Add tidyselect support
     cols <- as_name(ensym(columns))
-    if (!all(cols %in% fk_cols)) {
-      abort_is_not_fkc(table_name, cols, ref_table_name, fk_cols)
-    }
   }
 
   dm_rm_fk_impl(dm, table_name, cols, ref_table_name)
 }
 
 dm_rm_fk_impl <- function(dm, table_name, cols, ref_table_name) {
-
   # FIXME: compound keys
   cols <- as.list(cols)
 
@@ -245,7 +263,13 @@ dm_rm_fk_impl <- function(dm, table_name, cols, ref_table_name) {
   i <- which(def$table == ref_table_name)
 
   fks <- def$fks[[i]]
-  fks <- fks[fks$table != table_name | is.na(vctrs::vec_match(fks$column, cols)), ]
+
+  ii <- fks$table != table_name | is.na(vctrs::vec_match(fks$column, cols))
+  if (all(ii)) {
+    abort_is_not_fkc(table_name, cols, ref_table_name)
+  }
+
+  fks <- fks[ii, ]
   def$fks[[i]] <- fks
 
   new_dm3(def)
@@ -366,7 +390,7 @@ check_fk <- function(t1, t1_name, colname, t2, t2_name, pk) {
     left_join(t1_join, t2_join, by = "value") %>%
       # if value is NULL, this also counts as a match -- consistent with fk semantics
       mutate(mismatch_or_null = if_else(is.na(match), value, NULL)) %>%
-      count(mismatch_or_null) %>%
+      safe_count(mismatch_or_null) %>%
       ungroup() %>% # dbplyr problem?
       mutate(n_mismatch = sum(if_else(is.na(mismatch_or_null), 0L, n), na.rm = TRUE)) %>%
       mutate(n_total = sum(n, na.rm = TRUE)) %>%
@@ -401,3 +425,48 @@ check_fk <- function(t1, t1_name, colname, t2, t2_name, pk) {
     "{tick(glue('{t1_name}${colname}'))} not in {tick(glue('{t2_name}${pk}'))}: {vals_formatted}"
   )
 }
+
+
+# Errors ------------------------------------------------------------------
+
+abort_fk_exists <- function(child_table_name, colnames, parent_table_name) {
+  abort(
+    error_txt_fk_exists(
+      child_table_name, colnames, parent_table_name
+    ),
+    .subclass = dm_error_full("fk_exists")
+  )
+}
+
+error_txt_fk_exists <- function(child_table_name, colnames, parent_table_name) {
+  glue(
+    "({commas(tick(colnames))}) is alreay a foreign key of table ",
+    "{tick(child_table_name)} into table {tick(parent_table_name)}."
+  )
+}
+
+abort_is_not_fkc <- function(child_table_name, colnames,
+                             parent_table_name) {
+  abort(
+    error_txt_is_not_fkc(
+      child_table_name, colnames, parent_table_name
+    ),
+    .subclass = dm_error_full("is_not_fkc")
+  )
+}
+
+error_txt_is_not_fkc <- function(child_table_name, colnames,
+                                 parent_table_name) {
+  glue(
+    "({commas(tick(colnames))}) is not a foreign key of table ",
+    "{tick(child_table_name)} into table {tick(parent_table_name)}."
+  )
+}
+
+abort_rm_fk_col_missing <- function() {
+  abort(error_txt_rm_fk_col_missing(), .subclass = dm_error_full("rm_fk_col_missing"))
+}
+
+error_txt_rm_fk_col_missing <- function() {
+  "Parameter `columns` has to be set. Pass `NULL` for removing all references."
+}
