@@ -14,7 +14,7 @@ test_that("error messages do not change", {
     abort_not_bijective("child_table_name", "fk_col_name")
     abort_not_injective("child_table_name", "fk_col_name")
     abort_ref_tbl_has_no_pk("parent_table")
-    abort_is_not_fkc("child_table_name", c("wrong_fk_colname", "and_one_more"), "parent_table_name", c("actual_fk_colname", "and_one_more"))
+    abort_is_not_fkc("child_table_name", c("wrong_fk_colname", "and_one_more"), "parent_table_name")
     abort_rm_fk_col_missing()
     abort_last_col_missing()
     abort_no_cycles()
@@ -28,6 +28,8 @@ test_that("error messages do not change", {
     abort_no_unique_indexes()
     abort_need_named_vec(c("activity", "income", "expenses", "loss_or_gain"))
     abort_key_constraints_need_db()
+    abort_pk_not_defined("table")
+    abort_fk_exists("child", c("child_1", "child_2"), "parent")
     abort_first_rm_fks("parent", c("child_1", "child_2"))
     abort_no_src_or_con()
     abort_update_not_supported()
@@ -45,7 +47,8 @@ test_that("error messages do not change", {
     abort_con_only_for_dbi()
     abort_only_possible_wo_zoom("dm_zoom_to")
     abort_only_possible_w_zoom("dm_update_zoomed")
-    abort_req_tbl_not_avail(c("dull", "boring", "common_knowledge"), c("fascinating", "interesting"))
+    abort_learn_keys()
+    abort_tbl_access("accessdenied")
     abort_unnamed_table_list()
     abort_need_unique_names("clone")
     abort_fk_not_tracked("hook", "eye")
@@ -57,7 +60,7 @@ test_that("error messages do not change", {
     abort_only_named_args("give_names", "frobnicability")
     abort_wrong_syntax_set_cols()
     abort_temp_table_requested(c("i_am_temporary", "i_am_permanent"), "i_am_permanent")
-    # abort_pk_not_tracked("house", "house_number")
-    # abort_only_for_local_src(mtcars)
+    abort_pk_not_tracked("house", "house_number")
+    abort_only_for_local_src(mtcars)
   })
 })
